const { Adw, Gio, GLib, Gtk } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const _ = ExtensionUtils.gettext;


function init() {
    ExtensionUtils.initTranslations(Me.metadata.uuid);
}


function fillPreferencesWindow(window) {
    const settings = ExtensionUtils.getSettings();

    // Create a preferences page, with a single group
    const page = new Adw.PreferencesPage();
    window.add(page);

    const group = new Adw.PreferencesGroup();
    page.add(group);

    // Create a new preferences row
    const row = new Adw.ActionRow({ title: _('Search engine') });
    group.add(row);

    // Loading list of search engines
    const searchEngineFile = Me.dir.get_child('search-engines.json');
    const [, contents, etag] = searchEngineFile.load_contents(null);
    const decoder = new TextDecoder();
    const json = JSON.parse(decoder.decode(contents));
    const searchEngineNames = json.map(d => d.name);

    const list = new Gtk.StringList({ strings: searchEngineNames }); 
    
    const dropdown = new Gtk.DropDown();
    dropdown.set_model(list);

    settings.bind('search-engine', dropdown, 'selected',
        Gio.SettingsBindFlags.DEFAULT);

    // Add the switch to the row
    row.add_suffix(dropdown);
    row.activatable_widget = dropdown;

    // Make sure the window doesn't outlive the settings object
    window._settings = settings;
}
